Crate kcode_kennedy_orchestration

Crate kcode_kennedy_orchestration 

Structs

Api
ApiError
Config
LocalServices
Manuals
Orchestrator
RuntimeModel
Application-selected primary model facts used mechanically by a session.
Session
SessionRuntime
SessionService
TurnDeadline
Absolute enclosing deadline that remains transient during a turn.

Enums

AgentMode
TurnCompletion
TurnDeadlineKind
Kind of finite enclosing deadline supplied by the workflow owner.

Functions

build
data_url
persist_record
run
telegram_caption_for